use springPackage;

facet spring_system is

   outer_d :: real;
   outer_OD :: real;
   outer_ID :: real;
   outer_G :: real is 11.5E6;	// music wire
   outer_N :: real;
   outer_p :: real;
   inner_d :: real;
   inner_OD :: real;
   inner_ID :: real;
   inner_G :: real is 11.5E6;	// music wire
   inner_N :: real;
   inner_p :: real;

   system_L :: real;		// system free length

   system_R :: real;		// system rate
   inner_R :: real;
   outer_R :: real;

   system_deflection :: real;
   inner_deflection :: real;
   outer_deflection :: real;

   force :: real;

begin logic

   outer_spring: spring( outer_d, outer_OD, outer_ID,
			 outer_G, outer_N, outer_p);

   inner_spring: spring( inner_d, inner_OD, inner_ID,
			 inner_G, inner_N, inner_p);

   C1: outer_OD < 2.5;		// outer spring must fit inside 2.5" tube
   C2: outer_ID > inner_OD;	// outer spring must fit over inner spring
   C3: inner_ID > 1.0;		// inner spring must fit over 1.0" tube

   F1: system_L = (outer_spring.L max inner_spring.L);
   C4: system_L < 12.0;

   C5: system_deflection >= 0.0 and system_deflection =< 6.0;

   F1: inner_deflection =
          if system_deflection < (system_L - inner_spring.L) then 0.0
	    else system_deflection - (system_L - inner_spring.L)
        endif;
   F2: outer_deflection =
          if system_deflection < (system_L - outer_spring.L) then 0.0
	  else system_deflection - (system_L - outer_spring.L)
      endif;

   F3: inner_R =
          if inner_deflection = 0.0 then 0.0
	  else inner_spring.R
      endif;
   F4: outer_R =
          if outer_deflection = 0.0 then 0.0
	  else outer_spring.R
      endif;

   F5: system_R = outer_R + inner_R;

   C6: system_R =
	  if system_deflection =< 4.0 then 50.0
	  else 75.0
      endif;

   F6: force = system_R * system_deflection;

   A1: (system_deflection = 0.0 => force = 0.0)
       and (system_deflection = 4.0 => force = 200.0)
       and (system_deflection = 6.0 => force = 350.0);

end spring_system;
use test_logic;



